[data-select-viewport],[data-combobox-viewport]{scrollbar-width:none!important;-ms-overflow-style:none!important;-webkit-overflow-scrolling:touch!important}[data-combobox-viewport]::-webkit-scrollbar{display:none!important}[data-select-viewport]::-webkit-scrollbar{display:none!important}.hide-spinners::-webkit-inner-spin-button,.hide-spinners::-webkit-outer-spin-button{-webkit-appearance:none;margin:0;display:none}.hide-spinners{-moz-appearance:textfield}
