@tailwind base;
@tailwind components;
@tailwind utilities;

@layer base {
	:root {
		--background: 0 0% 100%;
		--foreground: 240 10% 4%;
		--card: 0 0% 100%;
		--card-foreground: 240 10% 4%;
		--popover: 0 0% 100%;
		--popover-foreground: 240 10% 4%;
		--primary: 240 10% 4%;
		--primary-foreground: 0 0% 98%;
		--secondary: 240 5% 96%;
		--secondary-foreground: 240 6% 10%;
		--muted: 240 5% 96%;
		--muted-foreground: 240 4% 46%;
		--accent: 240 5% 96%;
		--accent-foreground: 240 6% 10%;
		--destructive: 0 72% 51%;
		--destructive-foreground: 0 0% 98%;
		--border: 240 6% 90%;
		--input: 240 6% 90%;
		--ring: 240 6% 10%;
		--radius: 0.5rem;
	}

	.dark {
		--background: 240 6% 10%;
		--foreground: 0 0% 95%;
		--card: 240 6% 10%;
		--card-foreground: 0 0% 95%;
		--popover: 240 4% 14%;
		--popover-foreground: 0 0% 95%;
		--primary: 0 0% 95%;
		--primary-foreground: 240 6% 10%;
		--secondary: 240 4% 16%;
		--secondary-foreground: 0 0% 95%;
		--muted: 240 4% 16%;
		--muted-foreground: 240 5% 65%;
		--accent: 240 4% 16%;
		--accent-foreground: 0 0% 95%;
		--destructive: 0 72% 62%;
		--destructive-foreground: 0 0% 95%;
		--border: 240 4% 28%;
		--input: 240 4% 28%;
		--ring: 240 5% 65%;
		--radius: 0.5rem;
	}
}

@layer base {
	* {
		@apply border-border;
	}
	body {
		@apply bg-background text-foreground;
	}
}
