<script lang="ts">
	import { Badge } from "$lib/components/ui/badge";
</script>

<div class="flex items-center gap-2 rounded-md bg-muted/50 px-3 py-2 text-sm text-muted-foreground">
	<Badge variant="outline" class="text-xs">complex</Badge>
	<span>Edit in <code class="font-mono text-xs">config.toml</code></span>
</div>
