import{c as d,m as g,u as l,b as m,n as i,o as b,p,t as v,v as h,w as k}from"./TwTPH6iZ.js";function x(n=!1){const s=d,e=s.l.u;if(!e)return;let f=()=>v(s.s);if(n){let o=0,t={};const _=h(()=>{let c=!1;const r=s.s;for(const a in r)r[a]!==t[a]&&(t[a]=r[a],c=!0);return c&&o++,o});f=()=>p(_)}e.b.length&&g(()=>{u(s,f),i(e.b)}),l(()=>{const o=m(()=>e.m.map(b));return()=>{for(const t of o)typeof t=="function"&&t()}}),e.a.length&&l(()=>{u(s,f),i(e.a)})}function u(n,s){if(n.l.s)for(const e of n.l.s)p(e);s()}k();export{x as i};
